==> openshift-client-4.13.1-sources.jar: io/fabric8/openshift/client/dsl/internal/ClusterOperatorOperationsImpl.java <==

                
  

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.DoneableClusterOperator;
import io.fabric8.openshift.api.model.ClusterOperator;
import io.fabric8.openshift.api.model.ClusterOperatorList;
import io.fabric8.openshift.api.model.DoneableClusterOperator;

import java.util.Map;
import java.util.TreeMap;


public class ClusterOperatorOperationsImpl extends OpenShiftOperation<ClusterOperator, ClusterOperatorList, DoneableClusterOperator, Resource<ClusterOperator, DoneableClusterOperator>> {

  public ClusterOperatorOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public ClusterOperatorOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("config.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("clusteroperators"));
    this.type = ClusterOperator.class;
    this.listType = ClusterOperatorList.class;
    this.doneableType = DoneableClusterOperator.class;
  }

  public ClusterOperatorOperationsImpl newInstance(OperationContext context) {
    return new ClusterOperatorOperationsImpl(context);
  }
  
  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}

==> openshift-client-5.3.2-sources.jar: io/fabric8/openshift/client/dsl/internal/ClusterOperatorOperationsImpl.java <==

                            
  

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.ClusterOperator;
import io.fabric8.openshift.api.model.ClusterOperatorBuilder;
import io.fabric8.openshift.api.model.ClusterOperatorList;

import java.util.Map;
import java.util.TreeMap;


public class ClusterOperatorOperationsImpl extends OpenShiftOperation<ClusterOperator, ClusterOperatorList, Resource<ClusterOperator>> {

  public ClusterOperatorOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public ClusterOperatorOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("config.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("clusteroperators"));
    this.type = ClusterOperator.class;
    this.listType = ClusterOperatorList.class;
  }

  public ClusterOperatorOperationsImpl newInstance(OperationContext context) {
    return new ClusterOperatorOperationsImpl(context);
  }

  @Override
  public ClusterOperator edit(Visitor... visitors) {
    return patch(new ClusterOperatorBuilder(getMandatory()).accept(visitors).build());
  }
 
  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}
